@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.6
+#!/usr/local/bin/python3.7
 
 ## Copyright (C) 2007, 2008, 2009, 2010, 2011, 2013, 2014 Red Hat, Inc.
 ## Author: Tim Waugh <twaugh@redhat.com>
@@ -78,11 +78,9 @@ class AuthDialog(Gtk.Dialog):
             field = auth_info_required[i]
             label = Gtk.Label (label=_(self.AUTH_FIELD.get (field, field)))
             label.set_alignment (0, 0.5)
-            grid.attach (label, 0, 1, i, i + 1)
             grid.attach (label, 0, i, 1, 1)
             entry = Gtk.Entry ()
             entry.set_visibility (field != 'password')
-            grid.attach (entry, 1, 2, i, i + 1, 0, 0)
             grid.attach (entry, 1, i, 1, 1)
             self.field_entry.append (entry)
 
@@ -235,6 +233,10 @@ class Connection:
 
     def _authloop (self, fname, fn, *args, **kwds):
         self._passes = 0
+        # remove signature if dbus is not being used and signature is provided
+        if not self._using_polkit():
+            kwds.pop('signature', None)
+
         c = self._connection
         retry = False
         while True:
