@@ -1,6 +1,6 @@
 ## system-config-printer
 
-## Copyright (C) 2006, 2007, 2008, 2009, 2010, 2011 Red Hat, Inc.
+## Copyright (C) 2006, 2007, 2008, 2009, 2010, 2011, 2012 Red Hat, Inc.
 ## Authors:
 ##  Tim Waugh <twaugh@redhat.com>
 ##  Florian Festi <ffesti@redhat.com>
@@ -19,31 +19,27 @@
 ## along with this program; if not, write to the Free Software
 ## Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-import gobject
-import gtk
+from debug import *
+from gi.repository import Gtk
 import cups
 import ppdippstr
 import re
 
+cups.require ("1.9.55")
+
 # Special IPP type
 class IPPResolution(tuple):
     def __new__ (cls, values):
-        try:
-            cls.UNITS_BY_VAL = { cups.IPP_RES_UNITS_INCH: "dpi",
-                                 cups.IPP_RES_UNITS_CM: "dpc" }
-            cls.UNITS_DEFAULT = cups.IPP_RES_UNITS_INCH
-        except AttributeError:
-            # Requires pycups > 1.9.55
-            cls.UNITS_BY_VAL = { 3: "dpi",
-                                  4: "dpc" }
-            cls.UNITS_DEFAULT = 3
+        cls.UNITS_BY_VAL = { cups.IPP_RES_PER_INCH: "dpi",
+                             cups.IPP_RES_PER_CM: "dpc" }
+        cls.UNITS_DEFAULT = cups.IPP_RES_PER_INCH
 
         cls.UNITS_BY_STR = {}
-        for v, s in cls.UNITS_BY_VAL.iteritems ():
+        for v, s in cls.UNITS_BY_VAL.items ():
             cls.UNITS_BY_STR[s] = v
 
         if isinstance (values, str):
-            matches = re.match ("(\d+)\D+(\d+)(.*)", values).groups ()
+            matches = re.match (r"(\d+)\D+(\d+)(.*)", values).groups ()
             xres = int (matches[0])
             yres = int (matches[1])
             units = cls.UNITS_BY_STR.get (matches[2], cls.UNITS_DEFAULT)
@@ -59,7 +55,7 @@ class IPPResolution(tuple):
         return self
 
     def __init__ (self, values):
-        return tuple.__init__ (self, (self.xres, self.yres, self.units))
+        return tuple.__init__ ((self.xres, self.yres, self.units))
 
     def __str__ (self):
         return "%sx%s%s" % (self.xres, self.yres,
@@ -73,8 +69,8 @@ def OptionWidget(name, v, s, on_change):
             for vv in v + s:
                 if not isinstance(vv, str): raise ValueError
             return OptionSelectMany(name, v, s, on_change)
-        print v, s
-        raise NotImplemented
+        print(v, s)
+        raise NotImplementedError
     else:
         if (isinstance(s, int) or
             isinstance(s, float) or
@@ -114,10 +110,10 @@ class OptionInterface:
         return None
 
     def get_current_value(self):
-        raise NotImplemented
+        raise NotImplementedError
 
     def is_changed(self):
-        raise NotImplemented
+        raise NotImplementedError
 
 class OptionAlwaysShown(OptionInterface):
     # States
@@ -143,13 +139,13 @@ class OptionAlwaysShown(OptionInterface):
         self.set_default (system_default)
         self.combobox_map = combobox_map
 
-        if (type(self.widget) == gtk.ComboBox and
-            self.widget.get_model () == None):
-            print "No ComboBox model for %s" % self.name
-            model = gtk.ListStore (gobject.TYPE_STRING)
+        if (type(self.widget) == Gtk.ComboBox and
+            self.widget.get_model () is None):
+            debugprint("No ComboBox model for %s" % self.name)
+            model = Gtk.ListStore (str)
             self.widget.set_model (model)
 
-        if combobox_map != None and ipp_type == int:
+        if combobox_map is not None and ipp_type == int:
             model = self.widget.get_model ()
             i = 0
             dict = {}
@@ -175,10 +171,10 @@ class OptionAlwaysShown(OptionInterface):
         """Set the original value of the option and the supported choices.
         The special value None for original_value resets the option to the
         system default."""
-        if (supported != None and
+        if (supported is not None and
             self.use_supported):
-            if (type(self.widget) == gtk.ComboBox and
-                (self.ipp_type == str or self.ipp_type == IPPResolution)):
+            if (type(self.widget) == Gtk.ComboBox and
+                self.ipp_type == str):
                 model = self.widget.get_model ()
                 model.clear ()
                 translations = ppdippstr.job_options.get (self.name)
@@ -188,9 +184,7 @@ class OptionAlwaysShown(OptionInterface):
                     i = 0
 
                 for each in supported:
-                    txt = each
-                    if self.ipp_type != str:
-                        txt = str (self.ipp_type (each))
+                    txt = str (self.ipp_type (each))
 
                     if translations:
                         self.combobox_map.append (txt)
@@ -202,16 +196,35 @@ class OptionAlwaysShown(OptionInterface):
 
                     iter = model.append ()
                     model.set_value (iter, 0, text)
-            elif (type(self.widget) == gtk.ComboBox and
+            elif type(self.widget) == Gtk.ComboBoxText:
+                self.widget.remove_all () # emits 'changed'
+                translations = ppdippstr.job_options.get (self.name)
+                if translations:
+                    self.combobox_map = []
+                    self.combobox_dict = dict()
+                    i = 0
+
+                for each in supported:
+                    txt = str (self.ipp_type (each))
+                    if translations:
+                        self.combobox_map.append (txt)
+                        text = translations.get (txt)
+                        self.combobox_dict[each] = text
+                        i += 1
+                    else:
+                        text = txt
+
+                    self.widget.append_text (text)
+            elif (type(self.widget) == Gtk.ComboBox and
                   self.ipp_type == int and
-                  self.combobox_map != None):
+                  self.combobox_map is not None):
                 model = self.widget.get_model ()
                 model.clear ()
                 for each in supported:
                     iter = model.append ()
                     model.set_value (iter, 0, self.combobox_dict[each])
 
-        if original_value != None:
+        if original_value is not None:
             self.original_value = self.ipp_type (original_value)
             self.set_widget_value (self.original_value)
             self.button.set_sensitive (True)
@@ -223,14 +236,14 @@ class OptionAlwaysShown(OptionInterface):
 
     def set_widget_value(self, ipp_value):
         t = type(self.widget)
-        if t == gtk.SpinButton:
+        if t == Gtk.SpinButton:
             return self.widget.set_value (ipp_value)
-        elif t == gtk.ComboBox:
+        elif t == Gtk.ComboBox or t == Gtk.ComboBoxText:
             if ((self.ipp_type == str or self.ipp_type == IPPResolution)
-                and self.combobox_map == None):
+                and self.combobox_map is None):
                 model = self.widget.get_model ()
                 iter = model.get_iter_first ()
-                while (iter != None and
+                while (iter is not None and
                        self.ipp_type (model.get_value (iter, 0)) != ipp_value):
                     iter = model.iter_next (iter)
                 if iter:
@@ -242,14 +255,14 @@ class OptionAlwaysShown(OptionInterface):
                 else:
                     index = ipp_value
                 return self.widget.set_active (index)
-        elif t == gtk.CheckButton:
+        elif t == Gtk.CheckButton:
             return self.widget.set_active (ipp_value)
         else:
-            raise NotImplemented
+            raise NotImplementedError(t, self.name)
 
     def get_widget_value(self):
         t = type(self.widget)
-        if t == gtk.SpinButton:
+        if t == Gtk.SpinButton:
             # Ideally we would use self.widget.get_value() here, but
             # it doesn't work if the value has been typed in and then
             # the Apply button immediately clicked.  To handle this,
@@ -261,23 +274,31 @@ class OptionAlwaysShown(OptionInterface):
             except ValueError:
                 # Can't convert result of get_text() to ipp_type.
                 return self.ipp_type (self.widget.get_value ())
-        elif t == gtk.ComboBox:
+        elif t == Gtk.ComboBox:
             if self.combobox_map:
                 return self.combobox_map[self.widget.get_active()]
-            if self.ipp_type == str or self.ipp_type == IPPResolution:
-                return self.widget.get_active_text ()
             return self.ipp_type (self.widget.get_active ())
-        elif t == gtk.CheckButton:
+        elif t == Gtk.ComboBoxText:
+            s = self.widget.get_active_text ()
+            if s is None:
+                # If the widget is being re-initialised, there will be
+                # a changed signal emitted at the point where there
+                # are no entries to select from.
+                s = self.system_default
+            if self.combobox_map:
+                return self.combobox_map (s)
+            return self.ipp_type (s)
+        elif t == Gtk.CheckButton:
             return self.ipp_type (self.widget.get_active ())
 
-        print t
-        raise NotImplemented
+        print(t, self.widget, self.ipp_type)
+        raise NotImplementedError
 
     def get_current_value(self):
         return self.get_widget_value ()
 
     def is_changed(self):
-        if self.original_value != None:
+        if self.original_value is not None:
             # There was a value set previously.
             if self.state == self.STATE_RESET:
                 # It's been removed.
@@ -339,7 +360,7 @@ class OptionAlwaysShownSpecial(OptionAlwaysShown):
         model.remove (model.get_iter_first ())
 
     def reinit(self, original_value, supported=None):
-        if original_value != None:
+        if original_value is not None:
             self.hide_special_choice ()
         else:
             self.show_special_choice ()
@@ -369,11 +390,11 @@ class Option(OptionInterface):
         label = name
         if not label.endswith (':'):
             label += ':'
-        self.label = gtk.Label(label)
+        self.label = Gtk.Label(label=label)
         self.label.set_alignment(0.0, 0.5)
 
     def get_current_value(self):
-        raise NotImplemented
+        raise NotImplementedError
 
     def is_changed(self):
         return (self.is_new or
@@ -389,7 +410,7 @@ class OptionSelectOne(Option):
     def __init__(self, name, value, supported, on_change):
         Option.__init__(self, name, value, supported, on_change)
 
-        self.selector = gtk.combo_box_new_text()
+        self.selector = Gtk.ComboBoxText()
         
         selected = None
         for nr, choice in enumerate(supported):
@@ -399,10 +420,10 @@ class OptionSelectOne(Option):
         if selected is not None:
             self.selector.set_active(selected)
         else:
-            print "Unknown value for %s: %s" % (name, value)
-            print "Choices:", supported
+            debugprint("Unknown value for %s: %s" % (name, value))
+            debugprint("Choices: %s" % (supported))
             if len(supported) > 0:
-                print "Selecting from choices:", supported[0]
+                debugprint("Selecting from choices:", supported[0])
                 self.selector.set_active(0)
         self.selector.connect("changed", self.changed)
 
@@ -413,22 +434,15 @@ class OptionSelectOne(Option):
 
 class OptionSelectOneResolution(OptionSelectOne):
     def __init__(self, name, value, supported, on_change):
-        try:
-            self.UNITS_BY_VAL = { cups.IPP_RES_UNITS_INCH: "dpi",
-                                  cups.IPP_RES_UNITS_CM: "dpc" }
-            self.UNITS_DEFAULT = cups.IPP_RES_UNITS_INCH
-        except AttributeError:
-            # Requires pycups > 1.9.55
-            self.UNITS_BY_VAL = { 3: "dpi",
-                                  4: "dpc" }
-            self.UNITS_DEFAULT = 3
-
+        self.UNITS_BY_VAL = { cups.IPP_RES_PER_INCH: "dpi",
+                              cups.IPP_RES_PER_CM: "dpc" }
+        self.UNITS_DEFAULT = cups.IPP_RES_PER_INCH
         self.UNITS_BY_STR = {}
-        for v, s in self.UNITS_BY_VAL.iteritems ():
+        for v, s in self.UNITS_BY_VAL.items ():
             self.UNITS_BY_STR[s] = v
 
         value = self.string (value)
-        supported = map (self.string, supported)
+        supported = list(map (self.string, supported))
         OptionSelectOne.__init__ (self, name, value, supported, on_change)
 
     def string(self, value):
@@ -436,7 +450,7 @@ class OptionSelectOneResolution(OptionSelectOne):
                             self.UNITS_BY_VAL.get (value[2], ""))
 
     def value(self, string):
-        matches = re.match ("(\d+)\D+(\d+)(.*)", string).groups ()
+        matches = re.match (r"(\d+)\D+(\d+)(.*)", string).groups ()
         return (int (matches[0]), int (matches[1]),
                 self.UNITS_BY_STR.get (matches[2], self.UNITS_DEFAULT))
 
@@ -448,7 +462,7 @@ class OptionSelectOneResolution(OptionSelectOne):
 class OptionSelectOneNumber(OptionSelectOne):
 
     def get_current_value(self):
-        return int(self.selector.get_active_text())
+        return int(self.selector.get_active_text() or 0)
 
 # ---------------------------------------------------------------------------
 
@@ -457,10 +471,10 @@ class OptionSelectMany(Option):
     def __init__(self, name, value, supported, on_change):
         Option.__init__(self, name, value, supported, on_change)
         self.checkboxes = []
-        vbox = gtk.VBox()
+        vbox = Gtk.VBox()
 
         for s in supported:
-            checkbox = gtk.CheckButton(label=s)
+            checkbox = Gtk.CheckButton.new_with_label(s)
             checkbox.set_active(s in value)
             vbox.add(checkbox)
             checkbox.connect("toggled", self.changed)
@@ -486,8 +500,12 @@ class OptionNumeric(Option):
         if not isinstance(supported, tuple):
             supported = (0, supported)
         Option.__init__(self, name, value, supported, on_change)
-        adj = gtk.Adjustment(value, supported[0], supported[1], 1.0, 5.0, 0.0)
-        self.selector = gtk.SpinButton(adj, climb_rate=1.0, digits=digits)
+        adj = Gtk.Adjustment(value=value, lower=supported[0],
+                             upper=supported[1], step_increment=1.0,
+                             page_increment=5.0, page_size=0.0)
+        self.selector = Gtk.SpinButton()
+        self.selector.set_adjustment(adj)
+        self.selector.set_digits(digits)
         if not self.is_float:
             self.selector.set_numeric(True)
         self.selector.connect("changed", self.changed)
@@ -503,7 +521,7 @@ class OptionText(Option):
     def __init__(self, name, value, supported, on_change):
         Option.__init__(self, name, value, supported, on_change)
 
-        self.selector = gtk.Entry()
+        self.selector = Gtk.Entry()
         self.selector.set_text(value)
         self.selector.connect("changed", self.changed)
 
